'use strict';

var logger = require('./logger');

var OriginalServerConnector = require('../../main/js/ServerConnector');

var fs = require('fs');
var request = require('request');

var ServerConnectorMock = OriginalServerConnector;

ServerConnectorMock.init = function() {
  this._customMap = null;
  ServerConnectorMock.selectedLayout = null;
  ServerConnectorMock.zoomLevel = 2;
  ServerConnectorMock.listeners = [];

  ServerConnectorMock.selectedPolygon = null;
  ServerConnectorMock.exportModelId = null;

  // add listener types
  ServerConnectorMock.listeners.push("onActualizeSessionData");
  ServerConnectorMock.listeners.push("onActualizeParams");
  ServerConnectorMock.listeners.push("onSendClearRequest");
  ServerConnectorMock.listeners.push("onSendOverlayDetailDataRequest");
  ServerConnectorMock.listeners.push("onRequestUpdateCommentList");
  ServerConnectorMock.listeners.push("onSearchByCoord");
};
ServerConnectorMock.init();

ServerConnectorMock.addListener = function(type, fun) {
  if (ServerConnectorMock.listeners.indexOf(type) < 0) {
    throw new Error("Unknown listener type: " + type);
  }

  if (typeof fun !== "function") {
    throw new Error("Second parameter must be a function but \"" + typeof (fun) + "\" found.");
  }

  var listenerList = this.listeners[type];
  if (listenerList === null || listenerList === undefined) {
    listenerList = [];
    this.listeners[type] = listenerList;
  }
  listenerList.push(fun);
};

ServerConnectorMock.removeListener = function(type, fun) {
  if (ServerConnectorMock.listeners.indexOf(type) < 0) {
    throw new Error("Unknown listener type: " + type);
  }

  if (typeof fun !== "function") {
    throw new Error("Second parameter must be a function but \"" + typeof (fun) + "\" found.");
  }

  var listenerList = this.listeners[type];
  if (listenerList !== null && listenerList !== undefined) {
    var index = listenerList.indexOf(fun);
    if (index > -1) {
      listenerList.splice(index, 1);
    }
  }
};

ServerConnectorMock.callListeners = function(type, param) {

  if (ServerConnectorMock.listeners.indexOf(type) < 0) {
    throw new Error("Unknown listener type: " + type);
  }

  var listenerList = this.listeners[type];
  if (listenerList !== null && listenerList !== undefined) {
    logger.debug("ServerConnector is calling: " + type + ". " + listenerList.length + " listeners found.");
    for ( var i in listenerList) {
      var e = {};
      e.type = type;
      e.object = this;
      e.param = param;
      listenerList[i](e);
    }
  } else {
    logger.debug("ServerConnector is calling: " + type + ". No listeners found.");
  }
};

ServerConnectorMock.getLogoImg = function() {
  return "marker/empty.png";
};

ServerConnectorMock.getZoomLevel = function() {
  return this.zoomLevel;
};

ServerConnectorMock.setZoomLevel = function(value) {
  this.zoomLevel = value;
};

ServerConnectorMock.setCenterCoordinateX = function(value) {
  this.centerCoordinateX = value;
};

ServerConnectorMock.getCenterCoordinateX = function() {
  return this.centerCoordinateX;
};

ServerConnectorMock.setCenterCoordinateY = function(value) {
  this.centerCoordinateY = value;
};

ServerConnectorMock.getCenterCoordinateY = function() {
  return this.centerCoordinateY;
};

ServerConnectorMock.setSelectedLayout = function(value) {
  this.selectedLayout = value;
};

ServerConnectorMock.getSelectedLayout = function() {
  return this.selectedLayout;
};

ServerConnectorMock.setSelectedPolygon = function(value) {
  this.selectedPolygon = value;
};

ServerConnectorMock.getSelectedPolygon = function() {
  return this.selectedPolygon;
};

ServerConnectorMock.setExportModelId = function(value) {
  this.exportModelId = value;
};

ServerConnectorMock.getExportModelId = function() {
  return this.exportModelId;
};

ServerConnectorMock.actualizeSessionData = function() {
  ServerConnectorMock.callListeners("onActualizeSessionData");
};

ServerConnectorMock.actualizeParams = function() {
  ServerConnectorMock.callListeners("onActualizeParams");
};

ServerConnectorMock.setVisibleLayouts = function(value) {
  this.visibleLayouts = value;
};

ServerConnectorMock.getVisibleLayouts = function() {
  return this.visibleLayouts;
};

ServerConnectorMock.sendClearRequest = function(overlayName) {
  ServerConnectorMock.callListeners("onSendClearRequest", overlayName);
};

ServerConnectorMock.sendOverlayDetailDataRequest = function(overlayName, identifiedElement) {
  ServerConnectorMock.callListeners("onSendOverlayDetailDataRequest", overlayName, identifiedElement);
};

ServerConnectorMock.requestUpdateCommentList = function(modelId, latLngCoordinates) {
  ServerConnectorMock.callListeners("onRequestUpdateCommentList", [ modelId, latLngCoordinates ]);
};

ServerConnectorMock.searchByCoord = function(modelId, latLngCoordinates) {
  ServerConnectorMock.callListeners("onSearchByCoord", [ modelId, latLngCoordinates ]);
};

ServerConnectorMock.setCustomMap = function(customMap) {
  this._customMap = customMap;
};

ServerConnectorMock.getCustomMap = function() {
  return this._customMap;
};

ServerConnectorMock.addOverlayCollection = function(overlay) {
  logger.debug("Adding overlay: " + overlay);
};

ServerConnectorMock.sendRefreshRequest = function(overlayName) {
  logger.debug("Send refresh request: " + overlayName);
};

ServerConnectorMock.getMaxOverlayColorInt = function() {
  return 0xFF0000;
};

ServerConnectorMock.getMinOverlayColorInt = function() {
  return 0x00FF00;
};

ServerConnectorMock.readFile = function(url) {
  return new Promise(function(resolve, reject) {
    if (url.indexOf("http") === 0) {
      request.get(url, function(error, response, body) {
        if (error) {
          reject(error);
        } else if (response.statusCode !== 200) {
          reject(response);
        } else {
          resolve(body);
        }
      });
    } else {
      fs.readFile(url, 'utf8', function(err, content) {
        if (err) {
          reject(err);
        } else {
          resolve(content);
        }
      });
    }
  });
};

ServerConnectorMock.getServerBaseUrl = function() {
  return "./testFiles/apiCalls/";
};

ServerConnectorMock.getProjectUrl = function(projectId, token) {
  return this.getServerBaseUrl() + "project/getMetaData-" + projectId + "-" + token;
};

ServerConnectorMock.getConfigurationUrl = function(token) {
  return this.getServerBaseUrl() + "configuration/getAllValues-" + token;
};

ServerConnectorMock.getOverlaysUrl = function(projectId, token) {
  return this.getServerBaseUrl() + "overlay/getOverlayList-" + projectId + "-" + token;
};
ServerConnectorMock.getOverlayByIdUrl = function(overlayId, projectId, token) {
  return this.getServerBaseUrl() + "overlay/getOverlayById-" + overlayId + "-" + projectId + "-" + token;
};

ServerConnectorMock.getOverlayElementsUrl = function(overlayId, projectId, token) {
  return this.getServerBaseUrl() + "overlay/getOverlayElements-" + overlayId + "-" + projectId + "-" + token;
};

module.exports = ServerConnectorMock;
