"use strict";

require("./mocha-config");

var Alias = require("../../main/js/map/data/Alias");
var AbstractCustomMap = require("../../main/js/map/AbstractCustomMap");
var CustomMap = require("../../main/js/map/CustomMap");
var CustomMapOptions = require("../../main/js/map/CustomMapOptions");
var LayoutAlias = require("../../main/js/map/data/LayoutAlias");
var LayoutData = require("../../main/js/map/data/LayoutData");
var LayoutReaction = require("../../main/js/map/data/LayoutReaction");
var Model = require("../../main/js/map/data/MapModel");
var Project = require("../../main/js/map/data/Project");
var Reaction = require("../../main/js/map/data/Reaction");

function Helper() {
  this.idCounter = 1000000;
}

Helper.prototype.createProject = function() {
  var result = new Project();
  result.setId(this.idCounter++);
  result.setModel(this.createModel());
  return result;
};

Helper.prototype.createAlias = function() {
  var result = new Alias({
    idObject : this.idCounter++,
    name : "Test element",
    modelId : this.idCounter++,
    bounds : {
      x : 10.0,
      y : 20.0,
      width : 30.0,
      height : 40.0,
    },
  });
  return result;
};

Helper.prototype.createLayoutAlias = function() {
  var result = new LayoutAlias({
    idObject : this.idCounter++,
    value : 0.2,
    color : {
      a : 23
    },
    geneVariations : [ {} ]
  });
  return result;
};

Helper.prototype.createLayoutReaction = function() {
  var result = new LayoutReaction({
    idObject : this.idCounter++,
    width : 3.4,
    color : {
      a : 24,
    },
    reverse : true
  });
  return result;
};

Helper.prototype.createReaction = function(map) {
  var mapId = null;
  if (map !== undefined) {
    mapId = map.getId();
  } else {
    mapId = this.idCounter++;
  }
  var result = new Reaction({
    idObject : this.idCounter++,
    lines : [],
    centerPoint : new google.maps.Point(0, 0),
    modelId : mapId,
  });
  return result;
};

Helper.prototype.createOptions = function() {
  var map = this.createGoogleMap();

  var project = this.createProject();

  var options = {
    map : map,
    project : project,
    dataCollections : [ {
      name : "testCollection" + this.idCounter++,
    } ],
  };
  return options;
};

Helper.prototype.createModel = function() {
  var result = new Model();
  result.setId(this.idCounter++);
  result.setTileSize(256);
  result.setWidth(26547.3333333333);
  result.setHeight(800);
  result.setMaxZoom(8);
  result.setMinZoom(2);

  var layout = this.createLayout();
  result.addLayout(layout);
  return result;
};

Helper.prototype.createLayout = function() {
  var id = this.idCounter++;
  var layout = new LayoutData({
    idObject : id,
    name : "testLayout" + id,
  });
  return layout;
};

Helper.prototype.createGoogleMap = function() {
  var result = new google.maps.Map(testDiv, {
    center : {
      lat : -34.397,
      lng : 150.644
    },
    scrollwheel : false,
    zoom : 8
  });
  return result;
};

Helper.prototype.createCustomMapOptions = function() {
  var project = this.createProject();
  var map = this.createGoogleMap();
  var result = new CustomMapOptions({
    markerOptimization : true,
    project : project,
    map : map
  });

  return result;
};

Helper.prototype.createAbstractCustomMap = function() {
  var options = this.createCustomMapOptions();
  var result = new AbstractCustomMap(options.getProject().getModel(), options);

  return result;
};

Helper.prototype.createCustomMap = function() {
  var options = this.createCustomMapOptions();
  var result = new CustomMap(options);
  return result;
};

module.exports = Helper;
