"use strict";

var Alias = require('../../../../main/js/map/data/Alias');
var chai = require('chai');
var assert = chai.assert;
var logger = require('../../logger');

describe(
    'Alias',
    function() {
      beforeEach(function() {
        logger.flushBuffer();
      });

      it("contructor with invalid arg", function() {
        var jsonString = '{}';
        var javaObject = JSON.parse(jsonString);
        new Alias(javaObject);
        assert.equal(1, logger.getErrors().length, 1);
      });

      it("Alias simple contructor", function() {
        var jsonString = '{"bounds":{"x":190,"y":44,"width":80,"height":40},"modelId":57,"idObject":18554}';
        var javaObject = JSON.parse(jsonString);
        var alias = new Alias(javaObject);
        assert.equal(alias.isComplete(), false);
        assert.equal(null, alias.name);
        assert.equal(alias.getX(), 190);
      });

      it(
          "Alias update method",
          function() {
            var jsonString = '{"bounds":{"x":190,"y":44,"width":80,"height":40},"modelId":57,"idObject":18554}';
            var javaObject = JSON.parse(jsonString);
            var alias = new Alias(javaObject);
            var updateJsonString = '{"notes":"","type":"Protein","name":"s1","synonyms":[],"formerSymbols":[],"references":[],"other":[],"bounds":{"x":59,"y":73,"width":80,"height":40},"modelId":54,"idObject":18552}';
            var javaObject2 = JSON.parse(updateJsonString);
            alias.update(javaObject2);
            assert.ok(alias.isComplete());
            assert.equal('s1', alias.name);
          });

      it(
          "Alias update method 2",
          function() {
            var jsonString = '{"bounds":{"x":190,"y":44,"width":80,"height":40},"modelId":57,"idObject":18554}';
            var javaObject = JSON.parse(jsonString);
            var alias = new Alias(javaObject);
            var updateJsonString = '{"notes":"","type":"Protein","synonyms":[],"formerSymbols":[],"references":[],"other":[],"bounds":{"x":59,"y":73,"width":80,"height":40},"modelId":54,"idObject":18552}';
            var javaObject2 = JSON.parse(updateJsonString);
            alias.update(javaObject2);
            assert.equal(alias.isComplete(), false);
          });

      it(
          "Alias complex contructor",
          function() {
            var jsonString = '{"notes":"","type":"Protein","name":"s1","synonyms":[],"formerSymbols":[],"references":[],"other":[],"bounds":{"x":59,"y":73,"width":80,"height":40},"modelId":54,"idObject":18552}';
            var javaObject = JSON.parse(jsonString);
            var alias = new Alias(javaObject);
            assert.ok(alias.isComplete());
            assert.equal('s1', alias.name);
          });
    });
