"use strict";

var LayoutAlias = require('../../../../main/js/map/data/LayoutAlias');
var LayoutData = require('../../../../main/js/map/data/LayoutData');

var chai = require('chai');
var assert = chai.assert;

var logger = require('../../logger');

describe('LayoutData', function() {
  it("contructor", function() {
    var layoutId = 3;
    var name = "nm";
    var overlay = new LayoutData(layoutId, name);
    assert.equal(overlay.getId(), layoutId);
    assert.equal(overlay.getName(), name);
  });

  it("contructor from json obj", function() {
    var string = '{"modelId":15781,"name":"test","description":"test","status":"OK","progress":"0.00",'
        + '"directory":"5e8ff9bf55ba3508199d22e984129be6/sample0.0235076236865853214852",'
        + '"creator":"admin ","inputDataAvailable":"true","idObject":14852}';
    var obj = JSON.parse(string);
    var data = new LayoutData(obj);
    assert.ok(data);
    assert.equal(data.getInputDataAvailable(), true);
  });

  it("updateAlias", function() {
    var layoutId = 3;
    var name = "nm";
    var overlay = new LayoutData(layoutId, name);

    var aliasId = 4;
    var alias = new LayoutAlias({
      idObject : aliasId,
    });

    overlay.addAlias(alias);

    assert.equal(overlay.getAliasById(aliasId).getValue(), null);

    var val = 5;
    var alias2 = new LayoutAlias({
      idObject : aliasId,
      value : val,
    });
    overlay.updateAlias(alias2);

    assert.equal(overlay.getAliasById(aliasId).getValue(), val);

    assert.equal(logger.getWarnings().length, 0);
  });

  it("update invalid alias", function() {
    var layoutId = 3;
    var name = "nm";
    var overlay = new LayoutData(layoutId, name);

    var aliasId = 4;
    var alias = new LayoutAlias({
      idObject : aliasId,
    });

    overlay.updateAlias(alias);

    assert.equal(logger.getWarnings().length, 1);
  });
});
