"use strict";

var IdentifiedElement = require('../../../../main/js/map/data/IdentifiedElement');
var OverlayCollection = require('../../../../main/js/map/overlay/OverlayCollection');
var assert = require('assert');

describe('OverlayCollection', function() {
    var mapMock = {
      registerSource : function() {
      },
      refreshInfoWindows : function() {
      },
      updateInfoWindowForIdentifiedElement : function() {
      },
    };

it("constructor 1", function() {
  var oc = new OverlayCollection(mapMock, 'test name');
  assert.ok(oc);
});

it("constructor 2", function() {
  var oc = new OverlayCollection(mapMock, 'test name', true);
  assert.ok(oc);
});

it("constructor 3", function() {
  var oc = new OverlayCollection(mapMock, 'test name', false, true);
  assert.ok(oc);
});

it("updateOverviewElementDetailData", function() {
  var searchId = 'some_id';

  var oc = new OverlayCollection(mapMock, 'test name', true);
  assert.ok(oc);

  var javaObj = {
    objectId : "31165",
    modelId : 269,
    type : "alias",
    icon : "marker/marker/marker_red_1.png"
  };
  var javaObj2 = {
    objectId : "31166",
    modelId : 269,
    type : "alias",
    icon : "marker/marker/marker_red_1.png"
  };
  var ie = new IdentifiedElement(javaObj);
  var ie2 = new IdentifiedElement(javaObj2);

  var data = oc.getDetailDataByIdentifiedElement(ie, false);

  assert.deepEqual([], data);

  oc.setResultsIds([ searchId ]);

  var result = {
    field : 'val'
  };

  oc.updateOverviewElementDetailData(javaObj, searchId, result);

  data = oc.getDetailDataByIdentifiedElement(ie, false);
  assert.deepEqual(result, data[searchId]);

  var data2 = oc.getDetailDataByIdentifiedElement(ie2, false);
  assert.deepEqual(result, data[searchId]);
  assert.equal(null, data2[searchId]);

});
it("getMissingDetailDataIds", function() {
  var oc = new OverlayCollection(mapMock, 'test name', false, true);
  assert.ok(oc);

  var javaObj = {
    objectId : "31165",
    modelId : 269,
    type : "alias",
    icon : "marker/marker/marker_red_1.png"
  };
  var ie = new IdentifiedElement(javaObj);

  var data = oc.getMissingDetailDataIds(ie, true);

  assert.deepEqual([ null ], data);

  var result = {
    field : 'val'
  };

  oc.updateOverviewElementDetailData(javaObj, '__FULL__', result);

  data = oc.getMissingDetailDataIds(ie, true);

  assert.deepEqual([], data);
});
});

