"use strict";

var Helper = require('../../Helper');

var Reaction = require('../../../../main/js/map/data/Reaction');
var ReactionOverlay = require('../../../../main/js/map/overlay/ReactionOverlay');

var assert = require('assert');

var logger = require('../../logger');

describe('ReactionOverlay', function() {

  var helper;
  before(function() {
    helper = new Helper();
  });

  it("Constructor", function() {
    var map = helper.createAbstractCustomMap();

    var reaction = new ReactionOverlay(null, null, map, false);

    assert.ok(reaction.gmapObjects);
    assert.ok(reaction.getColor());
    assert.ok(reaction.getWidth());
    assert.ok(reaction.getBounds());

  });

  it("show", function() {
    var map = helper.createAbstractCustomMap();

    var javaObject = {
      lines : [ {
        start : Object,
        end : Object,
        type : "START"
      }, {
        start : Object,
        end : Object,
        type : "END"
      }, {
        start : Object,
        end : Object,
        type : "MIDDLE"
      } ],
      modelId : 319,
      idObject : "13178",
      centerPoint : new google.maps.Point(1, 2)
    };

    var react = new Reaction(javaObject);

    var reaction = new ReactionOverlay(null, react, map, false);

    reaction.hide();
    assert.equal(reaction.isShown(), false);

    reaction.show();
    assert.ok(reaction.isShown());

    assert.equal(logger.getWarnings().length, 0);

    reaction.show();
    assert.ok(reaction.isShown());
    assert.equal(logger.getWarnings().length, 1);

  });

  it("Constructor 2", function() {
    var map = helper.createAbstractCustomMap();

    var javaObject = {
      lines : [ {
        start : Object,
        end : Object,
        type : "START"
      }, {
        start : Object,
        end : Object,
        type : "END"
      }, {
        start : Object,
        end : Object,
        type : "MIDDLE"
      } ],
      modelId : 319,
      idObject : "13178"
    };

    var react = new Reaction(javaObject);
    var reaction = new ReactionOverlay(null, react, map, false);

    assert.ok(reaction.gmapObjects);
    assert.ok(reaction.getColor());
    assert.ok(reaction.getWidth());
    assert.ok(reaction.getBounds());
    assert.ok(reaction.getReactionData());
    assert.ok(reaction.getCustomMap());
    assert.ok(reaction.getId());
  });

  it("createline", function() {
    var map = helper.createAbstractCustomMap();

    var line = ReactionOverlay.createLine({
      start : {
        x : 0,
        y : 10
      },
      end : {
        x : 100,
        y : 100
      },
    }, "#000000", 3, map);

    assert.ok(line);

  });
});
