"use strict";

var Helper = require('./helper');

require("./mocha-config.js");

var minerva = require('../../main/js/minerva');

var chai = require('chai');
var assert = chai.assert;
var logger = require('./logger');

describe('minerva global', function() {

  var helper;
  before(function() {
    helper = new Helper();
  });

  it('create', function() {
    var options = helper.createOptions();

    var result = minerva.create(options);
    assert.ok(result);
    assert.equal(logger.getWarnings().length, 1);
  });

  it('create with layout', function() {

    var project = helper.createProject();
    var map = helper.createGoogleMap();

    var layout = helper.createLayout();
    layout.setInputDataAvailable(false);
    var layoutName = layout.getName();
    var layoutId = layout.getId();

    project.getModel().addLayout(layout);

    GuiConnector.getParams["layout"] = layoutName;

    var options = {
      map : map,
      project : project,
      dataCollections : [ {
        name : "testCollection"
      } ],
    };

    var result = minerva.create(options);
    assert.ok(result);
    // input file is not available so it's the background
    assert.equal(result.getSelectedLayouts().length, 0);
    assert.equal(ServerConnector.getSelectedLayout(), "cv" + layoutId);
    assert.equal(logger.getWarnings().length, 1);
  });

  it('create with layout 2', function() {

    var project = helper.createProject();
    var map = helper.createGoogleMap();

    var layout = helper.createLayout();
    layout.setInputDataAvailable(true);
    var layoutName = layout.getName();

    project.getModel().addLayout(layout);

    GuiConnector.getParams["layout"] = layoutName;

    var options = {
      map : map,
      project : project,
      dataCollections : [ {
        name : "testCollection"
      } ],
    };

    var result = minerva.create(options);
    assert.ok(result);
    // input file is available so it's not the background file but overlay
    assert.equal(result.getSelectedLayouts().length, 1);
    assert.equal(logger.getWarnings().length, 1);
  });
});
